@@ -376,9 +376,8 @@ TWEAK_GROUPS = [
                                 "accel-profile",
                                 schema_filename="org.gnome.desktop.peripherals.gschema.xml"),
         GSettingsSwitchTweak(_("Pointer Location"),
-                             "org.gnome.settings-daemon.peripherals.mouse",
+                             "org.gnome.desktop.interface",
                              "locate-pointer",
-                              schema_filename="org.gnome.settings-daemon.peripherals.gschema.xml",
                               desc=_("Press the Ctrl key to highlight the pointer.")),
         GSettingsSwitchTweak(_("Middle Click Paste"),
                              "org.gnome.desktop.interface",
